@@ -2,11 +2,11 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .invoice import *
+from . import invoice
 
 
 def register():
     Pool.register(
-        Invoice,
-        InvoiceLine,
+        invoice.Invoice,
+        invoice.InvoiceLine,
         module='account_invoice_line_standalone', type_='model')
